Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Cmd ¶
type Cmd struct {
// Subcommands
Show showCmd `command:"show" description:"shows network history segments currently stored by the node"`
Load loadCmd `` /* 196-byte string literal not displayed */
Rollback rollbackCmd `` /* 173-byte string literal not displayed */
Fetch fetchCmd `` /* 178-byte string literal not displayed */
LatestHistorySegmentFromPeers latestHistorySegmentFromPeers `` /* 145-byte string literal not displayed */
LatestHistorySegment latestHistorySegment `command:"latest-history-segment" description:"latest-history-segment returns the id of the node's latest history segment"`
ListActivePeers listActivePeers `command:"list-active-peers" description:"list the active datanode peers"`
Copy copyCmd `command:"copy" description:"copy a history segment from network history to a file"`
}
Click to show internal directories.
Click to hide internal directories.